package com.utopiaindustries.hseobservationsapp.activities.InjuryRecordForms;

import android.app.DatePickerDialog;
import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.graphics.drawable.ColorDrawable;
import android.os.Bundle;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.AutoCompleteTextView;
import android.widget.Button;
import android.widget.DatePicker;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import androidx.activity.EdgeToEdge;
import androidx.appcompat.app.AlertDialog;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.graphics.Insets;
import androidx.core.view.ViewCompat;
import androidx.core.view.WindowInsetsCompat;
import androidx.lifecycle.ViewModelProvider;

import com.utopiaindustries.hseobservationsapp.R;
import com.utopiaindustries.hseobservationsapp.adapters.ShiftAdapter;
import com.utopiaindustries.hseobservationsapp.models.HseData.Shift;
import com.utopiaindustries.hseobservationsapp.utils.ProgressDialogFragment;
import com.utopiaindustries.hseobservationsapp.utils.StorageManager.StorageManager;
import com.utopiaindustries.hseobservationsapp.viewmodels.LoginViewModel;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.Locale;

public class InjuryFormOne extends AppCompatActivity {

    Button btnNext, btnFetch;
    LoginViewModel loginViewModel;
    EditText etEmpId, etEmployeeName, etEmployeeDesignation, etEmployeeTenure, etDate, etEmployeeType;
    ImageView imgBack;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        EdgeToEdge.enable(this);
        setContentView(R.layout.activity_injury_form_one);
        ViewCompat.setOnApplyWindowInsetsListener(findViewById(R.id.main), (v, insets) -> {
            Insets systemBars = insets.getInsets(WindowInsetsCompat.Type.systemBars());
            v.setPadding(systemBars.left, systemBars.top, systemBars.right, systemBars.bottom);
            return insets;
        });

        initializeLayouts();

        imgBack.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                alertExit(InjuryFormOne.this);
            }
        });

        btnFetch.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (etEmpId.getText().toString().isEmpty()) {
                    Toast.makeText(InjuryFormOne.this, "Please enter employee id", Toast.LENGTH_SHORT).show();
                    return;
                }
                loginViewModel.getEmployeeData(etEmpId.getText().toString());
            }
        });

        btnNext.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (isValidate()) {
                    StorageManager.getInstance().getInjuryRecordModel().get(0).setEmployeeId(Integer.parseInt(etEmpId.getText().toString()));
                    Intent intent = new Intent(InjuryFormOne.this, InjuryFormTwo.class);
                    startActivity(intent);
                }

            }
        });
    }

    public void alertExit(Context con) {
        ViewGroup viewGroup = findViewById(android.R.id.content);

        TextView dialogOkBtn, dialogCancelBtn;

        AlertDialog.Builder builder = new AlertDialog.Builder(con);
        View view1 = LayoutInflater.from(con).inflate(R.layout.custom_layout_for_exit, viewGroup, false);
        builder.setCancelable(false);
        builder.setView(view1);

        dialogOkBtn = view1.findViewById(R.id.dialogOkBtn);
        dialogCancelBtn = view1.findViewById(R.id.dialogCancelBtn);

        AlertDialog alertDialog = builder.create();
        alertDialog.getWindow().setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));

        dialogOkBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {

                alertDialog.dismiss();

                StorageManager.getInstance().clearInjuryRecordModule();
                finish();

            }
        });

        dialogCancelBtn.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {

                alertDialog.dismiss();

            }
        });

        alertDialog.show();
    }

    private void initializeLayouts() {

        btnNext = findViewById(R.id.btn_next);
        btnFetch = findViewById(R.id.btn_fetch);
        etEmpId = findViewById(R.id.et_employee_id_number);
        etEmployeeName = findViewById(R.id.et_employee_name);
        etEmployeeDesignation = findViewById(R.id.et_employee_designation);
        etEmployeeTenure = findViewById(R.id.et_employee_tenure);
        imgBack = findViewById(R.id.img_back);
        etEmployeeType = findViewById(R.id.et_employee_type);
        etDate = findViewById(R.id.et_date);

        loginViewModel = new ViewModelProvider(this).get(LoginViewModel.class);

        loginViewModel.getLoadingState().observe(this, isLoading -> {

            if (isLoading != null && isLoading) {
                showProgressDialog();
            } else {
                dismissProgressDialog();
            }
        });

        loginViewModel.getErrorMessage().observe(this, errorResponse -> {
            Toast.makeText(this, errorResponse, Toast.LENGTH_SHORT).show();
        });

        loginViewModel.getEmployeeLiveData().observe(this, employeeInfoResponse -> {
            if (employeeInfoResponse != null) {
                Log.e("Employee-Info: ",""+employeeInfoResponse.toString());

                etEmployeeName.setText(employeeInfoResponse.getFullName());
                etEmployeeDesignation.setText(employeeInfoResponse.getPositionTitle());
                etEmployeeTenure.setText(employeeInfoResponse.getEmployeeTenure());
                etDate.setText(employeeInfoResponse.getJoiningDate());
                etEmployeeType.setText(employeeInfoResponse.getWorkerType());

            }
        });
    }

    @Override
    public void onBackPressed() {
        StorageManager.getInstance().clearObservationModule();
        super.onBackPressed();

        alertExit(InjuryFormOne.this);
    }

    public void showProgressDialog() {
        ProgressDialogFragment progressDialog = new ProgressDialogFragment();
        progressDialog.setCancelable(false);
        progressDialog.show(getSupportFragmentManager(), "progressDialog");
    }

    public void dismissProgressDialog() {
        ProgressDialogFragment progressDialog = (ProgressDialogFragment)
                getSupportFragmentManager().findFragmentByTag("progressDialog");
        if (progressDialog != null) {
            progressDialog.dismiss();
        }
    }

    public boolean isValidate() {
        boolean returnValue = true;
        String message = "";

        if (etEmpId.getText().toString().isEmpty()) {
            message = "Employee ID is required.";
            returnValue = false;
        }

        if (!returnValue) {
            Toast.makeText(this, message, Toast.LENGTH_SHORT).show();
        }

        return returnValue;
    }
}